# 30/4/2015

##### The New Statistics with R, Chapter 3: Student's t-test

### Optional set-up
rm(list=ls(all=TRUE)) # Clear R workspace
# Turn off significance stars
options( show.signif.stars = FALSE )
# set working directory (customise to your own settings)
# setwd(...)
 
## Load all library packages used in this script:
library(SMPracticals) # Statistical Modelling Practicals
library(ggplot2)      # Grammer of Graphics package
library(arm)          # Applied Regression Modelling
library(reshape)      # Reshape package
# See chapter 2 R script for library installation

# linear model including pair and type
anova( lm(height~pair+type, data= darwin))
summary( lm(height~pair+type, data= darwin))

############################### Box 3.2 #################################
# This 'long' format is what we need for linear model analysis like ANOVA
# and to produce some types of graph
# But, for some uses (e.g. t-tests) we need 'wide' format:
# Using melt() and cast() from Hadley Wickham's reshape2 package
library(reshape2)
( mDarwin <- melt(darwin, id.vars= c("pot", "pair", "type"), measure.vars="height") ) 
# or in this case, simply:  melt(darwin)
# R reports: Using pot, pair, type as id variables
# the darwin dataframe rearranged in wide format using cast(): 
( darwide <- cast(mDarwin, pot + pair ~ variable + type) )
darwide$Differences <- darwide$height_Cross - darwide$height_Self
darwide # Box 3.2
#################

## Paired T-test
t.test(darwide$height_Cross, darwide$height_Self, paired= TRUE)

# One sample t test
t.test(darwide$Differences)

##### Box 3.3 #####
# t = difference/se
###################

# calculating the observed t value
( t.obs <- 2.6166/1.2182 )

# Calculating the SEM of the differences:
( se <- sd(darwide$Differences)/sqrt(15) ) 

#Box 3.4

################# Supplementary R code ###################
## Fig. 3.1: Quantiles of the t distribution for n = 1:30
# sample sizes n 1-30
( n <- 1:30 )
# Create a vector tcritical to hold critical values of t for P<0.05
( tcritical <- matrix(nrow=30,ncol=1,"NA") )
# For  loop of critical values of t
for(i in 1:30 ) 
	tcritical[i] <- qt(0.975, i)
	print(tcritical)
( tcritical <- as.numeric(tcritical) )
( tframe <- data.frame(tcritical, n) )
qplot(n, tcritical, geom = c("point", "path"), data = tframe,
      ylab="Critial values of t", xlab="Sample size", 
      main="Critial values of t for small samples (P<0.05)")+theme_bw()+
geom_hline(yintercept = 1.96, colour = "grey50")
dev.copy(postscript, file="Fig3-1.eps", height=3, width=5, horizontal=F, onefile=F)
dev.off()
#########

# Critical value of t using qt() function:
# qt(p, df, ncp, lower.tail = TRUE, log.p = FALSE)
( t.crit <- qt(0.975, df= 14) )

# 95% CI limits for the differences in height
( upr95 <- -2.6167 + t.crit * se )
( lwr95 <- -2.6167 - t.crit * se )

# Confint() function output:
confint( lm(height~pair+type, data= darwin) )

#Box3.5

########## Figure 3.2 ###########
# arm package coefplot() function
coefplot( lm(height~type, data= darwin), xlim= c(-5,0) )
# dev.copy(postscript, file="Fig3-2.eps", height=2, width=4, horizontal=F, onefile=F)
dev.off()
#########

# estimates and 95% CI limits for the differences in height
display( lm(height~pair+type, data= darwin) ) # intercept = crossed
# confint( lm(height~pair+type, data= darwin) )
darwin$type <- relevel(darwin$type, ref= "Self")
display( lm(height~pair+type, data= darwin) ) # intercept = selfed
# confint( lm(height~pair+type, data= darwin) )

# Figure 3.3: See Chapter 5

# Figure 3.4: See Chapter 5

########## Figure 3.5 ##########
# Residuals
par(mfrow=c(2,2))
plot(lm(height~type+pair, data= darwin))
# model without pair:
# plot(lm(height~type, data= darwin))
# dev.copy(postscript, file="Fig3-5.eps", height=8, width=8, horizontal=F, onefile=F)
dev.off()
#########

# Simulated residuals to calibrate eyeball tests:
norm.residuals <- rnorm(30, mean(darwin$height), sd(darwin$height))
qqnorm(norm.residuals) ; qqline(normal residuals)

#################### Supplementary R code ############################
# Unpaired t tests with equal and unequal variances
t.test(darwide$height.Cross, darwide$height.Self, var.equal= TRUE)
t.test(darwide$height.Cross, darwide$height.Self, var.equal= FALSE)
###################################################################
