# 25/5/2015

##### The New Statistics with R, Chapter 6: Interactions (I: ANOVA)

### Metadata
 # Data from: Hautier, Niklaus & Hector (2009) Science 324 p.636
 # 64 obs. of  4 variables:
 # Fert      : Fertiliser Applied (F+) or not (F-) [Factor with 2 levels] 
 # Light     : Light applied (L+) or not (L-) [Factor w/ 2 levels]
 # FL        : 4-level version of Fert and Light [Factor w/ 4 levels: F-L-; F-L+ etc] 
 # Biomass.m2: Aboveground biomass, g/m2 [continuous response variable] 

### Set up
rm(list=ls(all=TRUE)) # Clear R workspace
# set working directory (customise to your own settings)
# setwd("/.../...")
# Turn off significance stars
options( show.signif.stars = FALSE ) 

### Installing packages if required and you have internet
 # install.packages("arm")
 # install.packages("ggplot2")

### Loading all library packages used: 
library(arm)
library(ggplot2)

#### One-Way ANOVA of a 3-treatment subset of the data

### Data
oneway <- read.table(file.choose(), header = T) 
# NewStats_Chapter6_Data_OneWay.txt
# str(oneway)
# summary(oneway)

# Box 6.1:
oneway

########## Figure 6.1 ##########
# function for calculating means
midm <- function(x) mean(x)
# create object for full Y axis label including superscript:
ylabel <- expression(paste("Aboveground biomass (g m"^"-2",") "))
p1 <- qplot(FL, Biomass.m2, data= oneway, 
            xlab= "Light & Fertilisation treatments", ylab= ylabel)+theme_bw()+            
            theme(legend.position= "none")+
            geom_hline(yintercept=480, colour="red")
p1 + stat_summary( aes(colour = "Mean"), geom = "point", fun.y = midm)
# ggsave(file= "Fig6-1.eps")
dev.off()
#########

# Linear model analysis: One-way ANOVA with three treatment levels
mod1 <- lm(Biomass.m2~FL, data= oneway)

# Check residuals
par( mfrow=c(2,2) )
plot(mod1)

# estimates and intervals:
display(mod1)
confint(mod1)

#######################
# Boxes 6.2, 6.3, 6.4 #
#######################

#### Factorial ANOVA of the full 4-treatment data

Factorial <- read.table(file.choose(), header = TRUE) 
# NewStats_Chapter6_Data_Factorial.txt

### Box 6.5:
Factorial

# Additive expectation
coef(mod1)[1] + coef(mod1)[2] + coef(mod1)[3]
# 479.6122

######## Fig. 6.2 ########
midm <- function(x) mean(x)
p2 <- qplot(FL, Biomass.m2, data= Factorial, 
            xlab= "Light & Fertilisation treatments", 
            ylab= ylabel)+theme_bw()+            
            theme(legend.position= "none")+
            geom_hline(yintercept=480, colour="red")
p2 + stat_summary( aes(colour= "Mean"), geom = "point", fun.y= midm)
# ggsave(file= "Fig6-2.eps")
dev.off()
#########

# Cell means model using the 4-level factor
mod2 <- lm(Biomass.m2~FL, data= Factorial)
display(mod2)

# Factorial ANOVA: 
mod3 <- lm(Biomass.m2~Light+Fert+Light:Fert, data= Factorial) 
# equivalent shorthand:
# mod3 <- glm(Biomass.m2~Light*Fert, data= Factorial) 
display(mod3)

# Non-additive interaction effect estimate from mod2:
219-124 
# 95

# Mean for the light only treatment:
coef(mod3)[1] + coef(mod3)[2]
# 385.9188

# Mean for the fertilizer only treatment
coef(mod3)[1] + coef(mod3)[3]
# 449.4875

# Estimated mean for the combined treatment
coef(mod3)[1] + coef(mod3)[2] + coef(mod3)[3] + coef(mod3)[4]
# 575.0188 

# estimates and intervals
summary(mod3)
confint(mod3)

# model without interaction
mod4 <- lm(Biomass.m2~Light+Fert, data= Factorial) 
anova(mod3, mod4)

### Fig 6.3
par(mfrow= c(2,1))
with(Factorial, interaction.plot(Light, Fert, Biomass.m2) )
with(Factorial, interaction.plot(Fert, Light, Biomass.m2, xlab= "Fertilizer") )
# dev.copy(postscript, file="Fig6-3.eps", height= 12, width= 6, horizontal=F, onefile=F)
dev.off()
