# 23/6/2015

##### The New Statistics with R, Chapter 7: Interactions in ANCOVA

#### ANCOVA of Soya Bean yields in relation to water stress and atmospheric pollution

### Metadata
 # Source: Heggestad, H.E. and Lesser, V.M. (1990) Journal of Environmental Quality 19, p.488.
 # R package: Sleuth2
 # Dataframe: case1402; 30 obs. of  5 variables
 # Stress : Explanatory factor with 2 levels - "Well-watered", "Stressed"
 # SO2    : Explanatory variable - sulphur dioxide concentration in microliters per liter.
 # O3     : Explanatory variable - ozone concentration in microliters in microliters per liter.
 # Forrest: Response - yield of Forrest variety soja beans in Kg per ha.
 # William: Response - yield of William variety soja beans in Kg per ha.

### Set up
rm(list=ls(all=TRUE)) # Clear R workspace
# set working directory (customise to your own settings)
# setwd(...)

### Installing packages if required and you have access to the internet
 # install.packages("Sleuth2")
 # install.packages("arm")
 # install.packages("ggplot2")

### Loading all library packages used: 
library(arm)
library(ggplot2)
library(Sleuth2)

# Turn off significance stars
options( show.signif.stars = FALSE ) 

### DATA
library(Sleuth2)

## Box 7.2 ##
str(case1402)
case1402
########

## ANCOVA of Williams yield

# Fig. 7.1:  Panel plot of Williams yield:
xlabel <- expression(paste("Ozone (", mu ,"L L"^"-1",")" ))
ylabel <- expression(paste("Log Yield (kg ha"^"-1",") "))
qplot(O3, log(William), data= case1402, facets=.~Stress,
      geom= c("point", "smooth"), method= "lm",
      xlab= xlabel, ylab= ylabel, main= "Soya bean variety: 'William'") +theme_bw()
# ggsave(file= "Fig7.1.tiff")
dev.off()
#########

# ANCOVA with interaction term
w1 <- lm(log(William)~O3*Stress, data= case1402) 

# check residuals
# par( mfrow=c(1,2) )
# plot(w1, which=c(1,2))
# No major infringements of assumptions

# Coefficients for model with interaction:
display(w1)
confint(w1)
# No support for an interaction (CI clearly includes zero)
# Negative main effect of water
# Negative slope with Ozone

# Either present this full model as above...
# Or, simplify to a model with parallel slopes
# summary( lm( log(William)~O3+Stress, data= case1402 ) )
# confint( lm( log(William)~O3+Stress, data= case1402 ) )


## ANCOVA of William yield as a function of water stress and SO2

# Summary table t tests of coefficients
summary( lm(log(William)~SO2*Stress, data= case1402 ) )

# ANOVA table F tests
anova( lm(log(William)~SO2*Stress, data= case1402 ) )

# Only the test of the Non-Sig interaction is the same
# Anova main effects are significant (with NS interaction left in)
# t tests of coefficients suggest neither main effect is significant
# The F and t tests are equivalent for the interaction
# But not for the main effects if the interaction is retained 

# Removing the interaction...
summary( lm(log(William)~SO2+Stress, data= case1402 ) )
# causes main effects to be significant
# and similar to F tests of main effects (with NS interaction left in)

# In the model without interaction
# F = t^2 and the P values match as in the one-way ANOVA above
anova( lm(log(William)~SO2+Stress, data= case1402 ) )

# Fig. 7.2: Yield of William soya beans as a function of SO2 and water:
# creating objects for formatted axis labels
xlabel <- expression(paste("SO"["2"]," (", mu ,"L L"^"-1",")")) # check units
ylabel <- expression(paste("Log Yield (kg ha"^"-1",") "))
qplot(SO2, log(William), data= case1402, facets=.~Stress,
      geom= c("point", "smooth"), method= "lm",
      xlab= xlabel, ylab= ylabel, main= "Soya bean variety: 'William'") +theme_bw() 
# ggsave(file= "Fig7.2.tiff")
dev.off()

### General Linear Model for O3, SO2 & Stress including interactions:
summary( lm(log(William)~O3*SO2*Stress, data= case1402 ) )
anova( lm(log(William)~O3*SO2*Stress, data= case1402 ) )

### General Linear Model for O3, SO2 & Stress dropping interactions:
summary( lm(log(William)~O3+SO2+Stress, data= case1402 ) )


########################## Supplementary R code ##########################
## ANCOVA of Forrest yield
# Panel plot
xlabel <- expression(paste("Ozone (", mu ,"L L"^"-1",")" ))
ylabel <- expression(paste("Log Yield (kg ha"^"-1",") "))
qplot(O3, log(Forrest), data= case1402, facets=.~Stress,
      geom= c("point", "smooth"), method= "lm",
      xlab= xlabel, ylab= ylabel, main= "Soya bean variety: 'Forrest'") +theme_bw()
# lm with interaction term
f1 <- lm( log(Forrest)~O3*Stress, data= case1402 ) 
# check residuals
par( mfrow=c(1,2) ) ; plot(f1, which=c(1,2))
# no major problems with residuals
# Coefficiants for model with interaction:
display(f1) ; confint(f1)
# CI for interaction includes zero
# CI for difference in intercepts includes zero
# slope with Ozone is negative and outside CI
# Either present this full model as above...
# Or, simplify to a regression model with ozone only 
# summary( lm( log(Forrest)~Ozone, data= soya ) 
# conclusions are qualitatively the same
